==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/HeaderRowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderRowSeparatorDescription } from "./HeaderRowSeparatorDescription";
/**
 * @hidden
 */
export let HeaderRowSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderRowSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderRowSeparatorDescriptionMetadata.a == null) {
                HeaderRowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderRowSeparatorDescriptionMetadata.c(HeaderRowSeparatorDescriptionMetadata.a);
            }
            if (a.k(HeaderRowSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(HeaderRowSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            HeaderRowSeparatorDescriptionMetadata.b(a);
            a.ad("HeaderRowSeparator", () => new HeaderRowSeparatorDescription());
            a.ac("HeaderRowSeparator", HeaderRowSeparatorDescriptionMetadata.a);
        }
    }
    HeaderRowSeparatorDescriptionMetadata.$t = markType(HeaderRowSeparatorDescriptionMetadata, 'HeaderRowSeparatorDescriptionMetadata');
    HeaderRowSeparatorDescriptionMetadata.a = null;
    return HeaderRowSeparatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/HeaderRowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderRowSeparatorDescription } from "./HeaderRowSeparatorDescription";
/**
 * @hidden
 */
export let HeaderRowSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderRowSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderRowSeparatorDescriptionMetadata.a == null) {
                HeaderRowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderRowSeparatorDescriptionMetadata.c(HeaderRowSeparatorDescriptionMetadata.a);
            }
            if (a.k(HeaderRowSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(HeaderRowSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            HeaderRowSeparatorDescriptionMetadata.b(a);
            a.ae("HeaderRowSeparator", () => new HeaderRowSeparatorDescription());
            a.ad("HeaderRowSeparator", HeaderRowSeparatorDescriptionMetadata.a);
        }
    }
    HeaderRowSeparatorDescriptionMetadata.$t = markType(HeaderRowSeparatorDescriptionMetadata, 'HeaderRowSeparatorDescriptionMetadata');
    HeaderRowSeparatorDescriptionMetadata.a = null;
    return HeaderRowSeparatorDescriptionMetadata;
})();
